@@ -37,7 +37,6 @@ static HTMLObjectClass *parent_class = NULL;
 
 static void set_parent (HTMLObject *o, HTMLObject *tail, HTMLObject *parent);
 
-
 /* HTMLObject methods.  */
 
 static void
@@ -370,7 +369,7 @@ calc_min_width (HTMLObject *o,
 }
 
 static HTMLAnchor *
-find_anchor (HTMLObject *self, const char *name, gint *x, gint *y)
+find_anchor (HTMLObject *self, const gchar *name, gint *x, gint *y)
 {
 	HTMLClue *clue;
 	HTMLObject *obj;
